import { describe, test } from "node:test";
import assert from "node:assert";
import { sum } from "lodash";
import * as dateFns from "date-fns";
import { clickhouseClient, knex } from "./databases";

const twoHourAgo = dateFns.format(
  dateFns.subHours(new Date(), 2),
  "yyyy-MM-dd HH:mm:ss"
);

const now = dateFns.format(new Date(), "yyyy-MM-dd HH:mm:ss");

describe("Events", () => {
  test("clickhouse is healthy", async () => {
    const { data } = await (
      await clickhouseClient.query({
        query: `
        SELECT 
          hostName() AS host, 
          uptime() AS uptime_seconds, 
          version() AS clickhouse_version, 
          'OK' AS status
        FROM system.tables
        LIMIT 1;
      `,
      })
    ).json();
    const [{ status }] = data as any;
    assert.equal(status, "OK");
  });
  test("has inserted events", async () => {
    const query = knex("events")
      .count("")
      .whereBetween("created_at", [twoHourAgo, now])
      .toString();
    console.log(query);
    const { data } = (await (
      await clickhouseClient.query({
        query,
      })
    ).json()) as any;
    assert.notEqual(Number.parseInt(data[0]["count()"], 10), 0);
  });
  test("events have a country", async () => {
    const { data } = (await (
      await clickhouseClient.query({
        query: knex("events")
          .count()
          .where("created_at", ">", twoHourAgo)
          .groupBy("geo_ip_country")
          .toString(),
        format: "JSON",
      })
    ).json()) as any;
    assert.notEqual(sum(data.map((d) => Number.parseInt(d["count()"], 10))), 0);
  });
});
